Insert a callout-block fenced div of type 'note', which has a blue accent and a letter 'i' icon. Will embed text selected bythe user, otherwise skeleton help text will be inserted.
See also
Other stamp-callouts:
stamp_callout_caution(),
stamp_callout_important(),
stamp_callout_tip(),
stamp_callout_warning()