Insert a callout-block fenced div of type 'tip', which has an green accent and a lightbulb icon. Will embed text selected by the user, otherwise skeleton help text will be inserted.
See also
Other stamp-callouts:
stamp_callout_caution(),
stamp_callout_important(),
stamp_callout_note(),
stamp_callout_warning()