Insert a fenced div for a horizontal two-column layout with percentage widths in a Revealjs presentation slide. Will embed text selected by the user into the left column and helper text into the right, otherwise skeleton help text will be inserted into both columns.
See also
Other stamp-blocks:
stamp_aside(),
stamp_footer(),
stamp_notes(),
stamp_tabset()