Insert a custom footer div in a Revealjs presentation slide. Will include text selected by the user, otherwise skeleton help text will be inserted.
See also
Other stamp-blocks:
stamp_aside(),
stamp_columns(),
stamp_notes(),
stamp_tabset()
Insert a custom footer div in a Revealjs presentation slide. Will include text selected by the user, otherwise skeleton help text will be inserted.
Other stamp-blocks:
stamp_aside(),
stamp_columns(),
stamp_notes(),
stamp_tabset()