Insert a list-containing fenced div in a Revealjs presentation slide that is revealed incrementally. Will embed text selected by the user, otherwise skeleton help text will be inserted.
See also
Other stamp-lists:
stamp_nonincremental()
Insert a list-containing fenced div in a Revealjs presentation slide that is revealed incrementally. Will embed text selected by the user, otherwise skeleton help text will be inserted.
Other stamp-lists:
stamp_nonincremental()