Skip to contents

Insert a list-containing fenced div to a Revealjs presentation slide that is not revealed incrementally (overrides a global incremental reveal). Will embed text selected by the user, otherwise skeleton help text will be inserted.

Usage

stamp_nonincremental()

Value

Nothing. Text is updated in the active document.

Details

The output looks like this if the user hadn't selected any text:

::: {.nonincremental}
- List element A
- List element B
:::

See also

Other stamp-lists: stamp_incremental()