Insert a class that allows content to be scrolled if the slide is too small to hold it (place on the same line as the slide title).
See also
Other stamp-classes:
stamp_smaller()
Insert a class that allows content to be scrolled if the slide is too small to hold it (place on the same line as the slide title).
Other stamp-classes:
stamp_smaller()