Insert a class that makes the font smaller in a Revealjs presentation slide (place on the same line as the slide title).
See also
Other stamp-classes:
stamp_scrollable()
Insert a class that makes the font smaller in a Revealjs presentation slide (place on the same line as the slide title).
Other stamp-classes:
stamp_scrollable()