Insert a panel-tabset fenced div to a Revealjs presentation slide. Will embed text selected by the user into the first tab and skeleton help text into the second, otherwise skeleton help text will be inserted into both tabs.
See also
Other stamp-blocks:
stamp_aside(),
stamp_columns(),
stamp_footer(),
stamp_notes()