Insert a list-containing fenced div to a Revealjs presentation slide that is not revealed incrementally (overrides a global incremental reveal). Will embed text selected by the user, otherwise skeleton help text will be inserted.
See also
Other stamp-lists:
stamp_incremental()